—

# Werksoorten

Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo.

#### IJverige redacteur heeft een mooi tussenkopje gemaakt met rich editor

Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.

Dit is de filtervraag Yes No

1. Voorbereiden
2. Inventariseren
   1. 2.1 Werksoorten
      1. 2.1.1 Handgedragen machinewerk
      2. 2.1.2 Zitgebonden machinewerk zelfrijdende bosbouwmachines
      3. 2.1.3 Groenvoorzieningwerk en werken in natuurterrein
      4. 2.1.4 Onderhoud, werkplaats en opslag.
      5. 2.1.5 Maaiboten
      6. 2.1.6 Surveillance, inventarisatie en rondleidingen
      7. 2.1.7 Werken bij hoogspanningsleidingen
      8. 2.1.8 Kantoorwerk
   2. Bijzondere omstandigheden
3. Evalueren
4. Plan van aanpak
5. Rapporten
6. Account settings

Link to sector organisation | Disclaimer | About